# LICENSE for documentation

## Non-code content

Non-code content in this repository is available under the [Creative Commons Attribution 4.0 International license](https://creativecommons.org/licenses/by/4.0/).

## Attribution

Non-trivial use of any content from this repository requires proper attribution to the authors. For non-source code content, the easiest way to do this is to link back to our repository in a way that makes sense in your comment. For example:

> This document contains work from the Inspeqtor documentation, available under the [Creative Commons Attribution 4.0 International license](https://creativecommons.org/licenses/by/4.0/) and [accessible from their GitHub repository](https://github.com/PorametPat/inspeqtor).

For source code, please follow the instructions in the license.

If this guidance is insufficient or unclear, please open a GitHub issue to ask for help.
